#!/usr/bin/gnuplot

set colors classic
set term x11

set xl "D [km]"
set yl "N dN"

set xr [100.e-9:]
set yr [0.8:1.0e26]
set xtics 10
set mxtics 10
set ytics 10
set mytics 10
set tics format "10^{%T}"
set logscale xy
set tics front

set style line 1 lc 'red'
set style line 2 lc 'green'
set style line 3 lc 'blue'
set style line 4 lc 'cyan'
set style line 5 lc 'magenta'
set style line 6 lc 'gray'

tmp=  1.0; set arrow from tmp,graph 0 to tmp,graph 1 lt 0
tmp=  1.0e-3; set arrow from tmp,graph 0 to tmp,graph 1 lt 0

set arrow from 1.0e-3,200e8  to 1.0e-3,300e8  heads lc 'black'   front size graph 0.01,90 fixed
set arrow from 1.0e-3, 30e10 to 1.0e-3, 60e10 heads lc '#666666' front size graph 0.01,90 fixed
set arrow from 1.0e-3,100e10 to 1.0e-3,300e10 heads lc '#aaaaaa' front size graph 0.01,90 fixed

f_family0(x) = (6e7) * (x/0.1)**(-2.7)  # MB; steeper due to scaling law
#f_family1(x) = (10**3.04947554e+00) * x**(-2.91181685e+00)  # Karin
#f_family2(x) = (10**4.58870291e+00) * x**(-2.73133737e+00)  # Veritas
f_family3(x) = (10**2.60208155e+00) * x**(-4.01398126e+00)  # Koronis2

p "<awk '(NR>1)' sfd1.dat | ./hc_sfd.awk"        not w l  ls 1,\
  "<awk '(NR>1)' sfd1.dat_EDITED | ./hc_sfd.awk"     w lp ls 1 lw 2,\
  "<awk '(NR>1)' sfd2.dat | ./hc_sfd.awk"        not w l  ls 2,\
  "<awk '(NR>1)' sfd2.dat_EDITED | ./hc_sfd.awk"     w lp ls 2 lw 2,\
  "<awk '(NR>1)' sfd3.dat | ./hc_sfd.awk"        not w l  ls 3,\
  "<awk '(NR>1)' sfd3.dat_EDITED | ./hc_sfd.awk"     w lp ls 3 lw 2,\
  "MB_2018.dat_hc"                                   w l  ls 6,\
  "158_Koronis2_family.dat_hc"                       w l  ls 6,\
  "../../dat/Bottke_etal_2015.dat" u (10.**$1):(10.**$2) t "Bottke etal. (2015)" w p pt 7 lc 'gray',\
  "../../dat/Harris_etal_2015.dat" u (10.**$1):(10.**$2) t "Harris etal. (2015)" w p pt 7 lc 'gray',\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) not w p pt 7 lc 'gray',\
  "<echo 100.e-9 1.2e25" w p pt 1 ps 3 lw 3 lc '#0066ff' t "zodiacal cloud",\
  "<echo 100.e-9 1.3e24" w p pt 1 ps 3 lw 3 lc '#cc00ff' t "IRAS 2.1{/Symbol\260} band",\
  f_family0(x) not lc 'gray'    dt 2,\
  f_family3(x) not lc 'black'   dt 2

pa -1

set term png small
set out "gen_sfd.png"
rep


q

  "832_Karin_family.dat_hc"                          w l  ls 6,\
  "<awk '(NR>1)' sfd4.dat | ./hc_sfd.awk"        not w l  ls 4,\
  "<awk '(NR>1)' sfd4.dat_EDITED | ./hc_sfd.awk"     w lp ls 4 lw 2,\
  "<awk '(NR>1)' sfd5.dat | ./hc_sfd.awk"        not w l  ls 5,\
  "<awk '(NR>1)' sfd5.dat_EDITED | ./hc_sfd.awk"     w lp ls 5 lw 2,\
  f_family1(x) not lc '#ffaaff' dt 2,\
  f_family2(x) not lc '#0000cc' dt 2,\

